==> igniteui-angular-charts-18.0.0.tgz: package/esm2015/lib/WaterfallSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { HorizontalAnchoredCategorySeries } from "./HorizontalAnchoredCategorySeries";
import { Brush } from "igniteui-angular-core";
import { DependencyProperty } from "igniteui-angular-core";
import { List$1 } from "igniteui-angular-core";
import { SeriesLayerPropertyOverlay } from "./SeriesLayerPropertyOverlay";
import { runOn, delegateCombine, markType, markDep, fromEnum } from "igniteui-angular-core";
import { Defaults } from "./Defaults";
import { Rect } from "igniteui-angular-core";
import { Pool$1 } from "igniteui-angular-core";
import { Rectangle } from "igniteui-angular-core";
import { ArrayExtension } from "igniteui-angular-core";
import { ScalerParams } from "./ScalerParams";
import { PropertyMetadata } from "igniteui-angular-core";
import { truncate, isNaN_ } from "igniteui-angular-core";
import { AnchoredCategorySeriesView } from "./AnchoredCategorySeriesView";
import { BrushUtil } from "igniteui-angular-core";
/**
 * @hidden
 */
export let WaterfallSeries = /*@__PURE__*/ (() => {
    class WaterfallSeries extends HorizontalAnchoredCategorySeries {
        constructor() {
            super();
            this.ab = WaterfallSeries.$;
        }
        bb() {
            return new WaterfallSeries();
        }
        get_fr() {
            return true;
        }
        get_e6() {
            return true;
        }
        hb() {
            let a = super.hb();
            {
                let b = ((() => {
                    let $ret = new SeriesLayerPropertyOverlay();
                    $ret.r = true;
                    $ret.ad = "NegativeBrush";
                    $ret.p = true;
                    $ret.q = true;
                    return $ret;
                })());
                b.valueResolving = delegateCombine(b.valueResolving, runOn(this, this.qu));
                a.add(b);
            }
            {
                let c = ((() => {
                    let $ret = new SeriesLayerPropertyOverlay();
                    $ret.r = true;
                    $ret.ad = "NegativeOutline";
                    $ret.p = true;
                    $ret.q = true;
                    return $ret;
                })());
                c.valueResolving = delegateCombine(c.valueResolving, runOn(this, this.qu));
                a.add(c);
            }
            return a;
        }
        i0() {
            if (!isNaN_(this.iz)) {
                return super.i0();
            }
            return Defaults.h;
        }
        get_ev() {
            return true;
        }
        ci() {
            return new WaterfallSeriesView(this);
        }
        px(a) {
            super.px(a);
            this.aau = a;
        }
        preferredCategoryMode(a) {
            return 2;
        }
        get_e7() {
            return true;
        }
        qw(a, b) {
            super.qw(a, b);
            this.aa5 = a;
            this.aa6 = b;
        }
        ue() {
            return this.aa5;
        }
        uf() {
            return this.aa6;
        }
        co() {
            if (this.cp == 0) {
                return 2;
            }
            return super.co();
        }
        get_d1() {
            return true;
        }
        p5(a, b, c, d) {
            super.p5(a, b, c, d);
            switch (b) {
                case WaterfallSeries.$$p[3]:
                case WaterfallSeries.$$p[2]:
                case WaterfallSeries.$$p[0]:
                case WaterfallSeries.$$p[1]:
                    this.qm(false);
                    break;
            }
        }
        gf(a, b) {
            if (this.gi(a, b)) {
                return true;
            }
            if (this.vs(a, b)) {
                return true;
            }
            return false;
        }
        u5(a) {
            if (this.aau == null || this.aau.de == null || this.aau.de.count == 0 || this.xAxis == null) {
                return Rect.empty;
            }
            let b = this.aau.de;
            let c = this.up(a);
            let d = -1;
            let e = this.xAxis.ch;
            let f = this.u9.right * 2;
            if (e) {
                d = ArrayExtension.binarySearch$1(Rectangle.$, b, (g) => {
                    let h = this.aau.dl(g);
                    return (f - c.x) < (f - (h.left + h.width / 2)) ? -1 : ((f - c.x) > (f - (h.left + h.width / 2)) ? 1 : 0);
                });
            }
            else {
                d = ArrayExtension.binarySearch$1(Rectangle.$, b, (g) => {
                    let h = this.aau.dl(g);
                    return c.x < (h.left + h.width / 2) ? -1 : (c.x > (h.left + h.width / 2) ? 1 : 0);
                });
            }
            if (d < 0) {
                d = ~d;
                d--;
            }
            if (d < 0) {
                d = 0;
            }
            if (d > b.count - 1) {
                d = b.count - 1;
            }
            let g = d;
            let h = d;
            if (g < 0) {
                g--;
            }
            if (h < b.count - 1) {
                h++;
            }
            let i = this.aa7(g);
            let j = this.aa7(d);
            let k = this.aa7(h);
            let l = i.left + i.width / 2;
            let m = j.left + j.width / 2;
            let n = k.left + k.width / 2;
            let o = Math.abs(l - c.x);
            let p = Math.abs(m - c.x);
            let q = Math.abs(n - c.x);
            let r = i.containsPoint(c);
            let s = j.containsPoint(c);
            let t = k.containsPoint(c);
            if (p <= o && p <= q) {
                if (!e && t) {
                    return k;
                }
                if (e && r) {
                    return i;
                }
                return j;
            }
            if (o <= p && o <= q) {
                if (!e && s) {
                    return j;
                }
                return i;
            }
            if (q <= p && q <= o) {
                if (e && s) {
                    return j;
                }
                return k;
            }
            return Rect.empty;
        }
        aa7(a) {
            return this.aau.dk(a);
        }
        xc() {
            return 1;
        }
        n7(a, b) {
            super.n7(a, b);
            this.aau.de.count = 0;
        }
        get_y9() {
            return 1;
        }
        ib() {
            return this.aab.k4(this.cl.by, this.cl.bx, this.getEffectiveViewport1(this.cl));
        }
        yl(a, b) {
            let c = b;
            super.yl(a, b);
            let d = b.by;
            let e = b.bx;
            let f = this.getEffectiveViewport1(b);
            let g = this.aab.k4(d, e, f);
            let h = this.aav;
            let i = this.aaw;
            let j;
            let k = this.y7(b);
            let l = NaN;
            let m = c.de;
            let n;
            let o = 0;
            this.xa.a2(this, this.xu(), runOn(this, this.wv), this.x3(b), this.x4(b));
            this.xa.r = this.aav;
            this.xa.s = this.aaw;
            this.xa.k = this.aav;
            this.xa.l = this.aaw;
            let p = false;
            let q = this.xa.b;
            if (q != null) {
                p = true;
            }
            let r = this.aab.cn;
            let s = this.valueColumn.count;
            let t = a.f;
            let u = this.aab;
            let v = new ScalerParams(0, d, e, this.aab.ch, f);
            let w = this.tw;
            let x = this.aa5;
            let y = this.t0;
            let z = this.aa6 || y;
            if (a.f.count > 0) {
                j = a.f._inner[0][0] - 0.5 * g;
                let aa = a.f._inner[0][1];
                if (!isNaN_(aa)) {
                    if (aa > k) {
                        n = m.item(o);
                        o++;
                        c.dj(n, j, k);
                        n.width = g;
                        n.height = Math.abs(k - aa);
                        this.xa.ak = x;
                        this.xa.ag = x;
                        this.xa.al = z;
                        this.xa.ah = z;
                        this.xa.f = true;
                        let ab = this.xa.aw(s, 0)[0];
                        if (r && a.m != null && 0 < a.m.count) {
                            ab = truncate(Math.round(a.m._inner[0]));
                        }
                        if (p) {
                            this.yh(t, 0, s, u, v, b.q, ab);
                        }
                        this.xa.ad(n, false, false, false, false);
                        n.ap = this.xa.k;
                        n.aq = this.xa.l;
                    }
                    else {
                        n = m.item(o);
                        o++;
                        c.dj(n, j, aa);
                        n.width = g;
                        n.height = Math.abs(aa - k);
                        this.xa.ak = w;
                        this.xa.ag = w;
                        this.xa.al = y;
                        this.xa.ah = y;
                        this.xa.f = false;
                        let ac = this.xa.aw(s, o)[0];
                        if (r && a.m != null && o >= 0 && o < a.m.count) {
                            ac = truncate(Math.round(a.m._inner[o]));
                        }
                        if (p) {
                            this.yh(t, 0, s, u, v, b.q, ac);
                        }
                        this.xa.ad(n, false, false, false, false);
                        n.ap = this.xa.k;
                        n.aq = this.xa.l;
                    }
                    l = aa;
                }
                else {
                    l = k;
                }
            }
            for (let ad = 1; ad < a.f.count; ++ad) {
                let ae = a.f._inner[ad];
                j = a.f._inner[ad][0] - 0.5 * g;
                let af = ae[1];
                if (!isNaN_(af)) {
                    n = m.item(o);
                    o++;
                    c.dj(n, j, Math.min(l, af));
                    n.width = g;
                    n.height = Math.abs(l - af);
                    this.xa.ak = w;
                    this.xa.ag = w;
                    this.xa.al = y;
                    this.xa.ah = y;
                    this.xa.f = false;
                    let ag = this.xa.aw(s, o)[0];
                    if (r && a.m != null && o >= 0 && o < a.m.count) {
                        ag = truncate(Math.round(a.m._inner[o]));
                    }
                    if (l > af) {
                        if (p) {
                            this.yh(t, ad, s, u, v, b.q, ag);
                        }
                    }
                    else {
                        this.xa.ak = x;
                        this.xa.ag = x;
                        this.xa.al = z;
                        this.xa.ah = z;
                        this.xa.f = true;
                        if (p) {
                            this.yh(t, ad, s, u, v, b.q, ag);
                        }
                    }
                    this.xa.ad(n, false, false, false, false);
                    n.ap = this.xa.k;
                    n.aq = this.xa.l;
                    l = af;
                }
            }
            m.count = o;
            b.c1(a);
        }
        get useHighMarkerFidelity() {
            return this.xy;
        }
    }
    WaterfallSeries.$t = markType(WaterfallSeries, 'WaterfallSeries', HorizontalAnchoredCategorySeries.$);
    WaterfallSeries.$$p = markDep(DependencyProperty, PropertyMetadata, WaterfallSeries, 'raisePropertyChanged', ['NegativeBrush:aa5:aa1', [Brush.$, null], 'NegativeOutline:aa6:aa2', [Brush.$, null], 'RadiusX:aav:aa3', [1, 0], 'RadiusY:aaw:aa4', [1, 0]]);
    return WaterfallSeries;
})();
/**
 * @hidden
 */
export let WaterfallSeriesView = /*@__PURE__*/ (() => {
    class WaterfallSeriesView extends AnchoredCategorySeriesView {
        constructor(a) {
            super(a);
            this.dd = null;
            this.df = null;
            this.dm = new Rectangle();
            this.de = null;
            this.dd = a;
            this.de = ((() => {
                let $ret = new Pool$1(Rectangle.$);
                $ret.create = runOn(this, this.dn);
                $ret.activate = runOn(this, this.dg);
                $ret.disactivate = runOn(this, this.di);
                $ret.destroy = runOn(this, this.dh);
                return $ret;
            })());
        }
        au() {
            super.au();
            this.df = new List$1(Rectangle.$, 0);
            if (!this.q) {
                this.dd.vp = Defaults.c;
                this.dd.i5 = Defaults.i;
                this.dd.aa5 = Defaults.ah;
                this.dd.aa6 = Defaults.ai;
            }
        }
        dn() {
            let a = new Rectangle();
            this.df.add(a);
            a._visibility = 1;
            return a;
        }
        dg(a) {
            a._visibility = 0;
        }
        di(a) {
            a._visibility = 1;
        }
        dh(a) {
            this.df.remove(a);
        }
        dj(a, b, c) {
            let d = false;
            if (a.o != c) {
                d = true;
                a.o = c;
            }
            if (a.n != b) {
                d = true;
                a.n = b;
            }
            if (d) {
                this.as();
            }
        }
        ac(a) {
            return this.df._inner[a];
        }
        ab(a) {
            let b = this.df._inner[a];
            this.dm._visibility = b._visibility;
            this.dm.n = b.n;
            this.dm.o = b.o;
            this.dm.width = b.width;
            this.dm.height = b.height;
            let c = this.bs(a);
            this.dm._fill = c;
            this.dm._stroke = c;
            this.dm.ad = this.e.hv + 3;
            return this.dm;
        }
        a8(a, b) {
            super.a8(a, b);
            if (a.d) {
                for (let c = 0; c < this.df.count; c++) {
                    let d = this.aa(c, b);
                    this.bf(d, c, b);
                    a.w(d);
                }
            }
        }
        an(a) {
            super.an(a);
            let b = 0;
            let c = new List$1(Rectangle.$, 0);
            for (let d of fromEnum(this.de.a)) {
                c.add(d);
            }
            c.aa((e, f) => {
                if (e.n < f.n) {
                    return -1;
                }
                else if (e.n > f.n) {
                    return 1;
                }
                else {
                    return 0;
                }
            });
            for (let e of fromEnum(c)) {
                let f = "Negative";
                if (BrushUtil.d(e._fill, this.e.tw)) {
                    f = "Positive";
                }
                this.e.a4.exportRectangleData(a, e, "column" + b, ["Main", f]);
            }
            b++;
        }
        dk(a) {
            let b = this.de.item(a);
            return new Rect(0, b.n, b.o, b.width, b.height);
        }
        dl(a) {
            return new Rect(0, a.n, a.o, a.width, a.height);
        }
    }
    WaterfallSeriesView.$t = markType(WaterfallSeriesView, 'WaterfallSeriesView', AnchoredCategorySeriesView.$);
    return WaterfallSeriesView;
})();

==> igniteui-angular-charts-18.1.0.tgz: package/esm2015/lib/WaterfallSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { HorizontalAnchoredCategorySeries } from "./HorizontalAnchoredCategorySeries";
import { Brush } from "igniteui-angular-core";
import { DependencyProperty } from "igniteui-angular-core";
import { List$1 } from "igniteui-angular-core";
import { SeriesLayerPropertyOverlay } from "./SeriesLayerPropertyOverlay";
import { runOn, delegateCombine, markType, markDep, fromEnum } from "igniteui-angular-core";
import { Defaults } from "./Defaults";
import { Rect } from "igniteui-angular-core";
import { Pool$1 } from "igniteui-angular-core";
import { Rectangle } from "igniteui-angular-core";
import { ArrayExtension } from "igniteui-angular-core";
import { ScalerParams } from "./ScalerParams";
import { PropertyMetadata } from "igniteui-angular-core";
import { truncate, isNaN_ } from "igniteui-angular-core";
import { AnchoredCategorySeriesView } from "./AnchoredCategorySeriesView";
import { BrushUtil } from "igniteui-angular-core";
/**
 * @hidden
 */
export let WaterfallSeries = /*@__PURE__*/ (() => {
    class WaterfallSeries extends HorizontalAnchoredCategorySeries {
        constructor() {
            super();
            this.ab = WaterfallSeries.$;
        }
        bi() {
            return new WaterfallSeries();
        }
        get_f4() {
            return true;
        }
        get_fj() {
            return true;
        }
        hr() {
            let a = super.hr();
            {
                let b = ((() => {
                    let $ret = new SeriesLayerPropertyOverlay();
                    $ret.r = true;
                    $ret.ad = "NegativeBrush";
                    $ret.p = true;
                    $ret.q = true;
                    return $ret;
                })());
                b.valueResolving = delegateCombine(b.valueResolving, runOn(this, this.ru));
                a.add(b);
            }
            {
                let c = ((() => {
                    let $ret = new SeriesLayerPropertyOverlay();
                    $ret.r = true;
                    $ret.ad = "NegativeOutline";
                    $ret.p = true;
                    $ret.q = true;
                    return $ret;
                })());
                c.valueResolving = delegateCombine(c.valueResolving, runOn(this, this.ru));
                a.add(c);
            }
            return a;
        }
        ji() {
            if (!isNaN_(this.jh)) {
                return super.ji();
            }
            return Defaults.h;
        }
        get_e8() {
            return true;
        }
        cq() {
            return new WaterfallSeriesView(this);
        }
        qw(a) {
            super.qw(a);
            this.acc = a;
        }
        preferredCategoryMode(a) {
            return 2;
        }
        get_fk() {
            return true;
        }
        rw(a, b) {
            super.rw(a, b);
            this.acn = a;
            this.aco = b;
        }
        vp() {
            return this.acn;
        }
        vq() {
            return this.aco;
        }
        cw() {
            if (this.cx == 0) {
                return 2;
            }
            return super.cw();
        }
        get_eb() {
            return true;
        }
        q4(a, b, c, d) {
            super.q4(a, b, c, d);
            switch (b) {
                case WaterfallSeries.$$p[3]:
                case WaterfallSeries.$$p[2]:
                case WaterfallSeries.$$p[0]:
                case WaterfallSeries.$$p[1]:
                    this.rm(false);
                    break;
            }
        }
        gu(a, b) {
            if (this.gx(a, b)) {
                return true;
            }
            if (this.w8(a, b)) {
                return true;
            }
            return false;
        }
        wg(a) {
            if (this.acc == null || this.acc.dg == null || this.acc.dg.count == 0 || this.xAxis == null) {
                return Rect.empty;
            }
            let b = this.acc.dg;
            let c = this.v0(a);
            let d = -1;
            let e = this.xAxis.ch;
            let f = this.wk.right * 2;
            if (e) {
                d = ArrayExtension.binarySearch$1(Rectangle.$, b, (g) => {
                    let h = this.acc.dn(g);
                    return (f - c.x) < (f - (h.left + h.width / 2)) ? -1 : ((f - c.x) > (f - (h.left + h.width / 2)) ? 1 : 0);
                });
            }
            else {
                d = ArrayExtension.binarySearch$1(Rectangle.$, b, (g) => {
                    let h = this.acc.dn(g);
                    return c.x < (h.left + h.width / 2) ? -1 : (c.x > (h.left + h.width / 2) ? 1 : 0);
                });
            }
            if (d < 0) {
                d = ~d;
                d--;
            }
            if (d < 0) {
                d = 0;
            }
            if (d > b.count - 1) {
                d = b.count - 1;
            }
            let g = d;
            let h = d;
            if (g < 0) {
                g--;
            }
            if (h < b.count - 1) {
                h++;
            }
            let i = this.acp(g);
            let j = this.acp(d);
            let k = this.acp(h);
            let l = i.left + i.width / 2;
            let m = j.left + j.width / 2;
            let n = k.left + k.width / 2;
            let o = Math.abs(l - c.x);
            let p = Math.abs(m - c.x);
            let q = Math.abs(n - c.x);
            let r = i.containsPoint(c);
            let s = j.containsPoint(c);
            let t = k.containsPoint(c);
            if (p <= o && p <= q) {
                if (!e && t) {
                    return k;
                }
                if (e && r) {
                    return i;
                }
                return j;
            }
            if (o <= p && o <= q) {
                if (!e && s) {
                    return j;
                }
                return i;
            }
            if (q <= p && q <= o) {
                if (e && s) {
                    return j;
                }
                return k;
            }
            return Rect.empty;
        }
        acp(a) {
            return this.acc.dm(a);
        }
        yu() {
            return 1;
        }
        o2(a, b) {
            super.o2(a, b);
            this.acc.dg.count = 0;
        }
        get_aar() {
            return 1;
        }
        iu() {
            return this.abt.k5(this.ct.by, this.ct.bx, this.getEffectiveViewport1(this.ct));
        }
        z3(a, b) {
            let c = b;
            super.z3(a, b);
            let d = b.by;
            let e = b.bx;
            let f = this.getEffectiveViewport1(b);
            let g = this.abt.k5(d, e, f);
            let h = this.acd;
            let i = this.ace;
            let j;
            let k = this.aap(b);
            let l = NaN;
            let m = c.dg;
            let n;
            let o = 0;
            this.ys.a2(this, this.zc(), runOn(this, this.yd), this.zl(b), this.zm(b));
            this.ys.r = this.acd;
            this.ys.s = this.ace;
            this.ys.k = this.acd;
            this.ys.l = this.ace;
            let p = false;
            let q = this.ys.b;
            if (q != null) {
                p = true;
            }
            let r = this.abt.cn;
            let s = this.valueColumn.count;
            let t = a.f;
            let u = this.abt;
            let v = new ScalerParams(0, d, e, this.abt.ch, f);
            let w = this.u2;
            let x = this.acn;
            let y = this.u6;
            let z = this.aco || y;
            if (a.f.count > 0) {
                j = a.f._inner[0][0] - 0.5 * g;
                let aa = a.f._inner[0][1];
                if (!isNaN_(aa)) {
                    if (aa > k) {
                        n = m.item(o);
                        o++;
                        c.dl(n, j, k);
                        n.width = g;
                        n.height = Math.abs(k - aa);
                        this.ys.ak = x;
                        this.ys.ag = x;
                        this.ys.al = z;
                        this.ys.ah = z;
                        this.ys.f = true;
                        let ab = this.ys.aw(s, 0)[0];
                        if (r && a.m != null && 0 < a.m.count) {
                            ab = truncate(Math.round(a.m._inner[0]));
                        }
                        if (p) {
                            this.zz(t, 0, s, u, v, b.q, ab);
                        }
                        this.ys.ad(n, false, false, false, false);
                        n.ap = this.ys.k;
                        n.aq = this.ys.l;
                    }
                    else {
                        n = m.item(o);
                        o++;
                        c.dl(n, j, aa);
                        n.width = g;
                        n.height = Math.abs(aa - k);
                        this.ys.ak = w;
                        this.ys.ag = w;
                        this.ys.al = y;
                        this.ys.ah = y;
                        this.ys.f = false;
                        let ac = this.ys.aw(s, o)[0];
                        if (r && a.m != null && o >= 0 && o < a.m.count) {
                            ac = truncate(Math.round(a.m._inner[o]));
                        }
                        if (p) {
                            this.zz(t, 0, s, u, v, b.q, ac);
                        }
                        this.ys.ad(n, false, false, false, false);
                        n.ap = this.ys.k;
                        n.aq = this.ys.l;
                    }
                    l = aa;
                }
                else {
                    l = k;
                }
            }
            for (let ad = 1; ad < a.f.count; ++ad) {
                let ae = a.f._inner[ad];
                j = a.f._inner[ad][0] - 0.5 * g;
                let af = ae[1];
                if (!isNaN_(af)) {
                    n = m.item(o);
                    o++;
                    c.dl(n, j, Math.min(l, af));
                    n.width = g;
                    n.height = Math.abs(l - af);
                    this.ys.ak = w;
                    this.ys.ag = w;
                    this.ys.al = y;
                    this.ys.ah = y;
                    this.ys.f = false;
                    let ag = this.ys.aw(s, o)[0];
                    if (r && a.m != null && o >= 0 && o < a.m.count) {
                        ag = truncate(Math.round(a.m._inner[o]));
                    }
                    if (l > af) {
                        if (p) {
                            this.zz(t, ad, s, u, v, b.q, ag);
                        }
                    }
                    else {
                        this.ys.ak = x;
                        this.ys.ag = x;
                        this.ys.al = z;
                        this.ys.ah = z;
                        this.ys.f = true;
                        if (p) {
                            this.zz(t, ad, s, u, v, b.q, ag);
                        }
                    }
                    this.ys.ad(n, false, false, false, false);
                    n.ap = this.ys.k;
                    n.aq = this.ys.l;
                    l = af;
                }
            }
            m.count = o;
            b.c3(a);
        }
        get useHighMarkerFidelity() {
            return this.zg;
        }
    }
    WaterfallSeries.$t = markType(WaterfallSeries, 'WaterfallSeries', HorizontalAnchoredCategorySeries.$);
    WaterfallSeries.$$p = markDep(DependencyProperty, PropertyMetadata, WaterfallSeries, 'raisePropertyChanged', ['NegativeBrush:acn:acj', [Brush.$, null], 'NegativeOutline:aco:ack', [Brush.$, null], 'RadiusX:acd:acl', [1, 0], 'RadiusY:ace:acm', [1, 0]]);
    return WaterfallSeries;
})();
/**
 * @hidden
 */
export let WaterfallSeriesView = /*@__PURE__*/ (() => {
    class WaterfallSeriesView extends AnchoredCategorySeriesView {
        constructor(a) {
            super(a);
            this.df = null;
            this.dh = null;
            this.dp = new Rectangle();
            this.dg = null;
            this.df = a;
            this.dg = ((() => {
                let $ret = new Pool$1(Rectangle.$);
                $ret.create = runOn(this, this.dq);
                $ret.activate = runOn(this, this.di);
                $ret.disactivate = runOn(this, this.dk);
                $ret.destroy = runOn(this, this.dj);
                return $ret;
            })());
        }
        au() {
            super.au();
            this.dh = new List$1(Rectangle.$, 0);
            if (!this.q) {
                this.df.w1 = Defaults.c;
                this.df.jn = Defaults.i;
                this.df.acn = Defaults.ah;
                this.df.aco = Defaults.ai;
            }
        }
        dq() {
            let a = new Rectangle();
            this.dh.add(a);
            a._visibility = 1;
            return a;
        }
        di(a) {
            a._visibility = 0;
        }
        dk(a) {
            a._visibility = 1;
        }
        dj(a) {
            this.dh.remove(a);
        }
        dl(a, b, c) {
            let d = false;
            if (a.o != c) {
                d = true;
                a.o = c;
            }
            if (a.n != b) {
                d = true;
                a.n = b;
            }
            if (d) {
                this.as();
            }
        }
        ac(a) {
            return this.dh._inner[a];
        }
        ab(a) {
            let b = this.dh._inner[a];
            this.dp._visibility = b._visibility;
            this.dp.n = b.n;
            this.dp.o = b.o;
            this.dp.width = b.width;
            this.dp.height = b.height;
            let c = this.bs(a);
            this.dp._fill = c;
            this.dp._stroke = c;
            this.dp.ad = this.e.ic + 3;
            return this.dp;
        }
        a8(a, b) {
            super.a8(a, b);
            if (a.d) {
                for (let c = 0; c < this.dh.count; c++) {
                    let d = this.aa(c, b);
                    this.bf(d, c, b);
                    a.w(d);
                }
            }
        }
        an(a) {
            super.an(a);
            let b = 0;
            let c = new List$1(Rectangle.$, 0);
            for (let d of fromEnum(this.dg.a)) {
                c.add(d);
            }
            c.aa((e, f) => {
                if (e.n < f.n) {
                    return -1;
                }
                else if (e.n > f.n) {
                    return 1;
                }
                else {
                    return 0;
                }
            });
            for (let e of fromEnum(c)) {
                let f = "Negative";
                if (BrushUtil.d(e._fill, this.e.u2)) {
                    f = "Positive";
                }
                this.e.bb.exportRectangleData(a, e, "column" + b, ["Main", f]);
            }
            b++;
        }
        dm(a) {
            let b = this.dg.item(a);
            return new Rect(0, b.n, b.o, b.width, b.height);
        }
        dn(a) {
            return new Rect(0, a.n, a.o, a.width, a.height);
        }
    }
    WaterfallSeriesView.$t = markType(WaterfallSeriesView, 'WaterfallSeriesView', AnchoredCategorySeriesView.$);
    return WaterfallSeriesView;
})();
